::: spotify.api.API
    options:
      members:
        - get_playlist
        - change_playlist_details
        - get_playlist_items
        - update_playlist_items
        - add_items_to_playlist
        - remove_playlist_items
        - get_current_users_playlists
        - get_users_playlists
        - create_playlist
        - get_featured_playlists
        - get_categorys_playlists
        - get_playlist_cover_image
        - add_custom_playlist_cover_image
::: spotify.models.SimplePlaylist
::: spotify.models.Playlist
::: spotify.models.PlaylistTracks
::: spotify.models.PlaylistItem
::: spotify.models.Playlists